@@ -8,7 +8,6 @@ use strict;
 use warnings;
 
 require Exporter;
-require List::Util; # as it has the XS
 
 our @ISA = qw( Exporter );
 our @EXPORT_OK = qw(
@@ -16,16 +15,19 @@ our @EXPORT_OK = qw(
   subname set_subname
 );
 
-our $VERSION    = "1.40";
+our $VERSION    = "1.44";
 $VERSION   = eval $VERSION;
 
+require List::Util; # as it has the XS
+List::Util->VERSION( $VERSION ); # Ensure we got the right XS version (RT#100863)
+
 =head1 NAME
 
 Sub::Util - A selection of utility subroutines for subs and CODE references
 
 =head1 SYNOPSIS
 
-    use Sub::Util qw( set_prototype subname set_subname );
+    use Sub::Util qw( prototype set_prototype subname set_subname );
 
 =head1 DESCRIPTION
 
@@ -47,6 +49,8 @@ that its popularity warrants inclusion in a core module, which this is.
 
     my $proto = prototype( $code )
 
+I<Since version 1.40.>
+
 Returns the prototype of the given C<$code> reference, if it has one, as a
 string. This is the same as the C<CORE::prototype> operator; it is included
 here simply for symmetry and completeness with the other functions.
